@@ -37,7 +37,6 @@
 #include "abstractappearance.h"
 #include "iconthemesmodel.h"
 #include "fontshelpers.h"
-#include <qstringlistmodel.h>
 
 K_PLUGIN_FACTORY_WITH_JSON(GTKConfigKCModuleFactory, "kde-gtk-config.json", registerPlugin<GTKConfigKCModule>();)
 
@@ -109,21 +108,21 @@ GTKConfigKCModule::GTKConfigKCModule(QWidget* parent, const QVariantList& args )
     //UI changes
     connect(ui->cb_theme, SIGNAL(currentIndexChanged(int)), this, SLOT(appChanged()));
     connect(ui->cb_theme_gtk3, SIGNAL(currentIndexChanged(int)), this, SLOT(appChanged()));
-    connect(ui->checkBox_theme_gtk3_prefer_dark, &QAbstractButton::clicked, this, &GTKConfigKCModule::appChanged);
+    connect(ui->checkBox_theme_gtk3_prefer_dark, SIGNAL(clicked(bool)), this, SLOT(appChanged()));
     connect(ui->cb_cursor, SIGNAL(currentIndexChanged(int)), this, SLOT(appChanged()));
     connect(ui->cb_icon, SIGNAL(currentIndexChanged(int)), this, SLOT(appChanged()));
     connect(ui->cb_icon_fallback ,SIGNAL(currentIndexChanged(int)), this, SLOT(appChanged()));
-    connect(ui->font, &KFontRequester::fontSelected, this, &GTKConfigKCModule::appChanged);
+    connect(ui->font, SIGNAL(fontSelected(QFont)), this, SLOT(appChanged()));
     connect(ui->cb_toolbar_icons, SIGNAL(currentIndexChanged(int)), this, SLOT(appChanged()));
-    connect(ui->checkBox_icon_gtk_menus, &QAbstractButton::clicked, this, &GTKConfigKCModule::appChanged);
-    connect(ui->checkBox_icon_gtk_buttons, &QAbstractButton::clicked, this, &GTKConfigKCModule::appChanged);
+    connect(ui->checkBox_icon_gtk_menus, SIGNAL(clicked(bool)), this, SLOT(appChanged()));
+    connect(ui->checkBox_icon_gtk_buttons, SIGNAL(clicked(bool)), this, SLOT(appChanged()));
     connect(ui->buttonGroup_primary_button_warps_slider, SIGNAL(buttonToggled(QAbstractButton*, bool)), this, SLOT(appChanged()));
 
     //preview updates
     connect(ui->cb_icon_fallback, SIGNAL(activated(QString)), this, SLOT(makePreviewIconTheme()));
     connect(ui->cb_icon, SIGNAL(activated(QString)), this, SLOT(makePreviewIconTheme()));
-    connect(ui->gtk2Preview, &QAbstractButton::clicked, this, &GTKConfigKCModule::runGtk2IfNecessary);
-    connect(ui->gtk3Preview, &QAbstractButton::clicked, this, &GTKConfigKCModule::runGtk3IfNecessary);
+    connect(ui->gtk2Preview, SIGNAL(clicked(bool)), this, SLOT(runGtk2IfNecessary(bool)));
+    connect(ui->gtk3Preview, SIGNAL(clicked(bool)), this, SLOT(runGtk3IfNecessary(bool)));
     
     QMenu* m = new QMenu(this);
     m->addAction(QIcon::fromTheme("get-hot-new-stuff"), i18n("Download GTK2 themes..."), this, SLOT(showThemeGHNS()));
@@ -184,9 +183,9 @@ void GTKConfigKCModule::refreshLists()
 {
     refreshThemesUi(true);
 
-    const auto newFont = stringToFont(appareance->getFont());
-    if (newFont != ui->font->font())
-        ui->font->setFont(newFont);
+    QString font = appareance->getFont();
+//     Q_ASSERT(!font.isEmpty());
+    ui->font->setFont(stringToFont(font));
     
     ui->cb_toolbar_icons->setCurrentIndex(gtkToolbar[appareance->getToolbarStyle()]);
     
@@ -252,9 +251,6 @@ void GTKConfigKCModule::makePreviewIconTheme()
 
 void GTKConfigKCModule::appChanged()
 {
-    if (m_loading)
-        return;
-
     savePreviewConfig();
     emit changed(true);
 }
@@ -384,74 +380,22 @@ void GTKConfigKCModule::load()
 {
     m_saveEnabled = false;
     bool someCorrect = appareance->loadFileConfig();
-    m_loading = true;
     if(someCorrect) {
         refreshLists();
     } else {
         defaults();
     }
-    m_loading = false;
     
     m_saveEnabled = true;
 }
 
-class MyStringListModel : public QAbstractListModel
-{
-public:
-    MyStringListModel(const QStringList &texts, QObject* parent) : QAbstractListModel(parent), m_texts(texts)
-    {
-    }
-
-    QVariant data(const QModelIndex & index, int role) const override
-    {
-        if (role != Qt::DisplayRole || !index.isValid() || index.row()>=m_texts.count())
-            return {};
-
-        return m_texts[index.row()];
-    }
-
-    int rowCount(const QModelIndex & parent) const override { return parent.isValid() ? 0 : m_texts.count(); }
-
-    void setStrings(const QSet<QString> &list) {
-        const auto current = m_texts.toSet();
-
-        const auto oldRows = QSet<QString>(current).subtract(list);
-        const auto newRows = QSet<QString>(list).subtract(current);
-        if (!newRows.isEmpty()) {
-            beginInsertRows({}, m_texts.count(), m_texts.count() + newRows.count());
-            m_texts += newRows.toList();
-            endInsertRows();
-        }
-
-        int from = -1;
-        for(const auto &row: oldRows) {
-            for(; from<m_texts.count();) {
-                const auto idx = m_texts.indexOf(row, from);
-                if (idx<0)
-                    break;
-                beginRemoveRows({}, idx, idx);
-                m_texts.removeAt(idx);
-                endRemoveRows();
-                from = idx + 1;
-            }
-        }
-    }
-
-private:
-    QStringList m_texts;
-};
-
 void refreshComboSameCurrentValue(QComboBox* combo, const QString& temp, const QStringList& texts)
 {
-    const auto model = dynamic_cast<MyStringListModel*>(combo->model());
-    if (!model) {
-        combo->setModel(new MyStringListModel(texts, combo));
-    } else {
-        model->setStrings(texts.toSet());
-    }
-
-    const int idx = combo->findText(temp);
-    combo->setCurrentIndex(qMax(0, idx));
+    combo->clear();
+    combo->addItems(texts);
+    int idx = combo->findText(temp);
+    if(idx>=0)
+        combo->setCurrentIndex(idx);
 }
 
 void GTKConfigKCModule::refreshThemesUi(bool useConfig)
@@ -494,7 +438,7 @@ void GTKConfigKCModule::showDialogForInstall()
 {
     if(!installer) {
         installer =  new DialogInstaller(this);
-        connect(installer, &DialogInstaller::themeInstalled, this, &GTKConfigKCModule::refreshLists);
+        connect(installer, SIGNAL(themeInstalled()), SLOT(refreshLists()));
     }
     
     installer->exec();
@@ -505,7 +449,7 @@ void GTKConfigKCModule::showDialogForUninstall()
 {
     if(!uninstaller) {
         uninstaller = new DialogUninstaller(this, appareance);
-        connect(uninstaller, &DialogUninstaller::themeUninstalled, this, &GTKConfigKCModule::refreshLists);
+        connect(uninstaller, SIGNAL(themeUninstalled()), SLOT(refreshLists()));
     }
     
     uninstaller->refreshListsForUninstall();
